@@ -20,7 +20,10 @@ def google_trends():
         return None
 
 CWD = os.path.dirname(__file__)
-NLTK_PUNKT = f"{str(CWD)}/tokenizers/punkt/english.pickle"
+PUNKT_ONE = "/tokenizers/punkt/english.pickle"
+PUNKT_TWO = "/tokenizers/punkt/PY3/english.pickle"
+NLTK_PUNKT_ONE = f"{str(CWD)}{PUNKT_ONE}"
+NLTK_PUNKT_TWO = f"{str(CWD)}{PUNKT_TWO}"
 
 STOCKTICKERS = os.path.join(os.path.dirname(__file__), 'stocks.csv')
 SOURCES = Sources
